import IManifest from '../../interfaces/IManifest';

/** Receives a JSON-converted version of the manifest.xml file, and returns an easier to read JSON file */
export default function parsePatchManifest(manifestFile: any): IManifest {
  const out: IManifest = { current: -1, releases: {} };

  const PatchManifest = manifestFile.elements[0];

  //<RequiredRelease>289</RequiredRelease>
  const RequiredRelease = PatchManifest.elements[2];
  out.current = Number(RequiredRelease.elements[0].text);

  //<Releases><Release><Id>0</Id><SHA1>53678f8057e52896a8145dca5c188ab3f24fa55f</SHA1></Release></Releases>
  const Releases = PatchManifest.elements[7];
  Releases.elements.forEach((Release: any) => {
    const id = Release.elements[0].elements[0].text;
    const sha1 = Release.elements[1].elements[0].text;
    out.releases[id] = { sha1, from: [], to: [] };
  });

  //<ReleaseUpdatePaths><ReleaseUpdatePath><From>287</From><To>288</To><ExtraDataItem>...</ExtraDataItem></ReleaseUpdatePath></ReleaseUpdatePaths
  const ReleaseUpdatePaths = PatchManifest.elements[8];
  ReleaseUpdatePaths.elements.forEach((ReleaseUpdatePath: any) => {
    const from = ReleaseUpdatePath.elements[0].elements[0].text;
    const to = ReleaseUpdatePath.elements[1].elements[0].text;
    //Release -1 does not exist but is a valid "from", e.g. for -1to0
    if (from !== '-1') {
      out.releases[from].to.push(Number(to));
    }
    out.releases[to].from.push(Number(from));
  });

  return out;
}
