import * as stream from 'stream';

/** Returns a promise that resolves as soon as the given stream has the given number of bytes ready for reading. */
export default function waitReadableLength(inputStream: stream.Readable, minLength: number): Promise<void> {
  return new Promise((resolve) => {
    const interval = setInterval(() => {
      if (inputStream.readableLength >= minLength) {
        clearInterval(interval);
        resolve();
      }
    }, 100);
  });
}
